@@ -16,7 +16,7 @@ class Buildpack:
         return script
 
     def dockerfiles(self, entrypoint):
-        python = f'''FROM ubuntu:20.04\nWORKDIR /app\nRUN apt-get update && apt-get install -y python3-pip\nCOPY requirements.txt .\nRUN yes | pip install -r requirements.txt\nCOPY . .\nEXPOSE 8000\nCMD {entrypoint}'''
+        python = f'''FROM python:3.9.5-slim-buster\nWORKDIR /app\nCOPY requirements.txt .\nRUN pip install -r requirements.txt\nCOPY . .\nEXPOSE 8000\nCMD {entrypoint}'''
         return python
 
     def generateDockerfile(self, file, save_location):
