@@ -1,4 +1,4 @@
-from sh_buildpack import Buildpack
+from buildpack import Buildpack
 bp = Buildpack(f"myapp")
 if __name__ == "__main__":
     bp.generateDockerfile("./Shonkufile")
\ No newline at end of file
